#  Copyright: Copyright (c) 2020., Adam Jakab
#
#  Author: Adam Jakab <adam at jakab dot pro>
#  Created: 3/27/20, 3:52 PM
#  License: See LICENSE.txt

__author__ = u'Adam Jakab'
__email__ = u'adam@jakab.pro'
__copyright__ = u'Copyright (c) 2020, {} <{}>'.format(__author__, __email__)
__license__ = u'License :: OSI Approved :: MIT License'
__version__ = u'0.0.3'
__status__ = u'Kickstarted'

__PACKAGE_TITLE__ = u'YearFixer'
__PACKAGE_NAME__ = u'beets-yearfixer'
__PACKAGE_DESCRIPTION__ = u'A beets plugin for fixing `original_year` and `year` tags on audio items.',
__PACKAGE_URL__ = u'https://github.com/adamjakab/BeetsPluginYearFixer'
__PLUGIN_NAME__ = u'yearfixer'
__PLUGIN_ALIAS__ = None
__PLUGIN_SHORT_DESCRIPTION__ = u'fix `original_year` and `year` tags on library items'
